from __future__ import print_function
import SimpleITK as sitk
import subprocess, sys, os

def n4_normalization(input_filename,workdir="workdir",output_filename="image_N4.nii"):
	os.chdir(os.path.dirname(__file__))
	path = os.getcwd()
	res = path + "/" + workdir + "/" + output_filename
	try:
		inputImage = sitk.ReadImage( input_filename )

		# if len ( argv ) > 4:
		#     maskImage = sitk.ReadImage( argv[4] )
		# else:
		#     maskImage = sitk.OtsuThreshold( inputImage, 0, 1, 200 )

		# if len ( argv ) > 3:
		#     inputImage = sitk.Shrink( inputImage, [ int(argv[3]) ] * inputImage.GetDimension() )
		#     maskImage = sitk.Shrink( maskImage, [ int(argv[3]) ] * inputImage.GetDimension() )

		inputImage = sitk.Cast( inputImage, sitk.sitkFloat32 )
		corrector = sitk.N4BiasFieldCorrectionImageFilter();
		numberFittingLevels = 4

		# if len ( argv ) > 6:
		#     numberFittingLevels = int( argv[6] )

		# if len ( argv ) > 5:
		#     corrector.SetMaximumNumberOfIterations( [ int( argv[5] ) ] *numberFittingLevels  )

		output = corrector.Execute( inputImage )
		sitk.WriteImage( output, res )
	except Exception as e:
		print("We got an Exception in n4")
		print(e)
		res = False;

	return res


import subprocess, os

def acpc_correction(input_filename,workdir="/workdir",output_filename="image_N4_acpc.nii",template_filename="vbm_template.nii",mat_filename="mat_N4_acpc.mat"):

	os.chdir(os.path.dirname(__file__))
	path = os.getcwd()

	workdir = path + workdir
	template_filename = path + "/template/" + template_filename
	output_filename = workdir + "/" + output_filename
	mat_filename = workdir + "/" + mat_filename

	process = None
	args = (path,workdir,input_filename,template_filename,output_filename,mat_filename)
	res = output_filename

	try:
		process = subprocess.Popen('sh %s/bin/ACPCAlignment.sh --workingdir=%s --in=%s --ref=%s --out=%s --omat=%s > log.txt'%args, shell=True)
		process.wait()
	except Exception as e:
		print("We got an Exception")
		print(e)

	return res


import subprocess, os

def skull_stripping(input_filename,workdir="/workdir",output_filename="image_N4_acpc_ss03.nii"):

	os.chdir(os.path.dirname(__file__))
	path = os.getcwd()

	workdir = path + workdir
	output_filename = workdir + "/" + output_filename

	process = None
	args = (input_filename,output_filename)
	res = output_filename

	try:
		process = subprocess.Popen('/usr/local/fsl/bin/bet %s %s -B -f 0.3 -g 0 > log.txt'%args, shell=True)
		process.wait()
	except Exception as e:
		print("We got an Exception in ss03")
		print(e)

	return res


from .intensity_normalization import n4_normalization
from .acpc_correction import acpc_correction
from .skull_stripping import skull_stripping
from .segmentation import gm_segmentation, wm_segmentation
from .normalization import normalization
from .smoothing import smoothing


import subprocess, os

def gm_segmentation(input_filename,workdir="/workdir"):

	os.chdir(os.path.dirname(__file__))
	path = os.getcwd()

	workdir = path + workdir
	output_basename = workdir + "/" + input_filename.split("/")[-1].split(".")[0]

	process = None
	args = (output_basename,input_filename)
	res = output_basename + "_seg_1"

	try:
		process = subprocess.Popen('/usr/local/fsl/bin/fast -t 1 -n 3 -g -o %s %s > log.txt'%args, shell=True)
		process.wait()
	except Exception as e:
		print("We got an Exception in segmentation")
		print(e)

	return res

def wm_segmentation(input_filename,workdir="/workdir"):

	os.chdir(os.path.dirname(__file__))
	path = os.getcwd()

	workdir = path + workdir
	output_basename = workdir + "/" + input_filename.split("/")[-1].split(".")[0]

	process = None
	args = (output_basename,input_filename)
	res = output_basename + "_seg_0"

	try:
		process = subprocess.Popen('/usr/local/fsl/bin/fast -t 1 -n 3 -g -o %s %s > log.txt'%args, shell=True)
		process.wait()
	except Exception as e:
		print("We got an Exception in segmentation")
		print(e)

	return res


from setuptools import setup, find_packages

setup(name='neuropot',
      version='0.1.2',
      description='NeuroPot is a library which provides automated processing of neuroradiological images, data cleaning and manipulation functionality, machine learning algorithms and transfer learning methods.',
      url='https://github.com/MEDCOMP/neuropot',
      author='Abhinit Ambastha',
      author_email='abhinit@comp.nus.edu.sg',
      license='MIT',
      packages=find_packages(),
      install_requires=[
      	'SimpleITK'
      ],
      zip_safe=False)